@@ -42,8 +42,8 @@ class BindApp(app_module.App):
                                tags=manifest.tags)
         self.add(info)
 
-        menu_item = menu.Menu('menu-bind', info.name, info.short_description,
-                              info.icon, 'bind:index',
+        menu_item = menu.Menu('menu-bind', info.name, info.icon, info.tags,
+                              'bind:index',
                               parent_url_name='system:visibility', order=30)
         self.add(menu_item)
 
